@@ -546,43 +546,38 @@ def delete_services_version(arguments):
         raise OperetoCliError('Cannot delete default service version.')
 
     logger.info('Searching for all services of version {} (may take some time..)'.format(service_version))
-    all_services = client.search_services(limit=50000)
+    all_services = client.delete_version_services(service_version)
     count = 0
     failed = 0
-    for service in all_services:
-        service_data = client.get_service(service['id'])
-        if service_version in service_data['versions']:
-            try:
-                client.delete_service_version(service_data['id'], service_version=service_version)
-                logger.info('Version {} of service {} has been deleted.'.format(service_data['id'], service_version))
-                count+=1
-            except OperetoCliError as e:
-                logger.error('Failed to delete version {} of service {}: {}'.format(service_data['id'], service_version, e.message))
-                failed+=1
+    if all_services is not None:
+        for service_id in all_services:
+            count += 1
+            logger.info('Version {} of service {} has been deleted.'.format(service_id, service_version))
 
     if count>0:
-        logger.info('Version {} has been removed from {} services.'.format(arguments['<service-version>'], count))
+        logger.info('Version {} has been removed from {} services.'.format(service_version, count))
         if failed > 0:
-            logger.error('Failed to remove version {} from {} services.'.format(arguments['<service-version>'], count))
+            logger.error('Failed to remove version {} from {} services.'.format(service_version, count))
     else:
-        logger.error('No services found for version {}.'.format(arguments['<service-version>']))
+        logger.error('No services found for version {}.'.format(service_version))
 
 
 def list_services_version(arguments):
-    logger.info('Listing all services of version {} (may take some time..)'.format(arguments['<service-version>']))
+    version = arguments['<service-version>']
+    logger.info('Listing all services of version {} (may take some time..)'.format(version))
     client = get_opereto_client()
-    all_services = client.search_services(limit=50000)
+    all_services = client.list_version_services(version)
     count=0
-    for service in all_services:
-        service_data = client.get_service(service['id'])
-        if arguments['<service-version>'] in service_data['versions']:
+    if all_services is not None:
+        for service_id in all_services:
+            print(service_id)
             count+=1
-            print(service_data['id'])
     if count>0:
         logger.info('{} services found for version {}.'.format(count, arguments['<service-version>']))
     else:
         logger.error('No services found for version {}.'.format(arguments['<service-version>']))
 
+
 def get_service_info(arguments):
     logger.info('Details of service {}:'.format(arguments['<service-name>']))
     client = get_opereto_client()
